==> modularRobotics-0.1.tar.gz: modularRobotics-0.1/setup.py <==
from distutils.core import setup
setup(
  name = 'modularRobotics',         # How you named your package folder (MyLib)
  packages = ['modularRobotics'],   # Chose the same as "name"
  version = '0.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'YOUR NAME',                   # Type in your name
  author_email = 'your.email@domain.com',      # Type in your E-Mail
  url = 'https://github.com/Fischchen/modular-robotics',   # Provide either the link to your github or to your website
  download_url = 'https://github.com/Fischchen/modular-robotics/archive/v0.1-alpha.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)

==> modularRobotics-0.1.1.tar.gz: modularRobotics-0.1.1/setup.py <==
import setuptools

with open("Readme.md", "r") as fh:
  long_desciption = fh.read()
 

setuptools.setup(
  name = 'modularRobotics',         # How you named your package folder (MyLib)
  packages = ['modularRobotics'],   # Chose the same as "name"
  version = '0.1.1',      # Start with a small number and increase it with every change you make
  license='MIT',        # Chose a license from here: https://help.github.com/articles/licensing-a-repository
  description = 'TYPE YOUR DESCRIPTION HERE',   # Give a short description about your library
  author = 'Fischchen',                   # Type in your name
  author_email = 'tipp.klever@gmail.com',      # Type in your E-Mail
  url = 'https://github.com/Fischchen/modular-robotics',   # Provide either the link to your github or to your website
  long_desciption=long_desciption,
long_description_content_type="text/markdown",
  download_url = 'https://github.com/Fischchen/modular-robotics/archive/v0.1-alpha.tar.gz',    # I explain this later on
  keywords = ['SOME', 'MEANINGFULL', 'KEYWORDS'],   # Keywords that define your package best
  install_requires=[            # I get to this in a second
          'validators',
          'beautifulsoup4',
      ],
  classifiers=[
    'Development Status :: 3 - Alpha',      # Chose either "3 - Alpha", "4 - Beta" or "5 - Production/Stable" as the current state of your package
    'Intended Audience :: Developers',      # Define that your audience are developers
    'Topic :: Software Development :: Build Tools',
    'License :: OSI Approved :: MIT License',   # Again, pick a license
    'Programming Language :: Python :: 3',      #Specify which pyhton versions that you want to support
    'Programming Language :: Python :: 3.4',
    'Programming Language :: Python :: 3.5',
    'Programming Language :: Python :: 3.6',
  ],
)
